@@ -172,7 +172,8 @@ int main(int argc, char **argv)
 	}
 	init_buffer();
  
-	if ((internal_link = libnet_open_link_interface(internal_dev, error)) == error) {
+	internal_link = libnet_open_link_interface(internal_dev, error);
+	if(!internal_link){
 		fprintf(stderr, "Libnet failure opening link interface: %s", error);
 		exit(1);
 	}
@@ -412,8 +413,9 @@ int main(int argc, char **argv)
 				packet_state->ip_src = x.ip->ip_src;
 				memcpy(packet_state->ether_dhost, x.eth->ether_dhost, ETHER_ADDR_LEN);
 				memcpy(packet_state->ether_shost, x.eth->ether_shost, ETHER_ADDR_LEN);
-				packet_state->last_packet=internal_pkthdr->ts;
-						
+					
+				packet_state->last_packet.tv_sec = internal_pkthdr->ts.tv_sec;
+				packet_state->last_packet.tv_usec = internal_pkthdr->ts.tv_usec; 
 				if(!stateless_ipt && add_entry(packet_key, packet_state) && verbose)
 				   fprintf(stdout, "Adding to state\n");
 				/* then rewrite and emit the new packet on the external interface! */
@@ -642,8 +644,8 @@ int main(int argc, char **argv)
  
 void minewt_usage() 
 { 
-   fprintf(stderr, "  minewt 1.0:   Userspace NAT/MAT Gateway\n"); 
-   fprintf(stderr, "Component of:   Paketto Keiretsu 1.0;    Dan Kaminsky  (dan@doxpara.com)\n\n");
+   fprintf(stderr, "  minewt %s:  Userspace NAT/MAT Gateway\n", VERSION); 
+   fprintf(stderr, "Component of:   Paketto Keiretsu %s;    Dan Kaminsky  (dan@doxpara.com)\n\n", VERSION);
    fprintf(stderr, "  Min. Usage:   minewt -i internal_ip -I external_ip -r gateway_ip\n");
    fprintf(stderr, "     Options:   -d/-D [device]: Internal/External Device\n");
    fprintf(stderr, "                -m/-M [MAC]   : Internal/External MAC Address\n");
