@@ -2,7 +2,7 @@
 #include "pk_crypt.h"
 
 
-struct frame *build_generic_syn();
+struct frame *build_generic_syn(struct frame *x);
 long bake_syncookie(u_char *ipp, u_char *key);
 long munch_syncookie(u_char *ipp, u_char *key);
 int raw_sock_syn_scan(char *dest, int length, char *dev, struct frame *scanx,
